@@ -5,14 +5,14 @@
 (defparameter *autoconf-prefix* "/usr/local")
 (defparameter *autoconf-exec_prefix* "/usr/local")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.27.0")
+(defparameter *autoconf-version* "5.28.0")
 (defparameter *autoconf-libdir* "/usr/local/lib")
 (defparameter *autoconf-libexecdir* "/usr/local/libexec")
 (defparameter *autoconf-datadir* "/usr/local/share")
-(defparameter *autoconf-infodir* "/usr/local/info")
+(defparameter *autoconf-infodir* "/usr/local/share/info")
 (defparameter *autoconf-host* "i686-pc-linux-gnu")
-(defparameter *autoconf-win32* "false")
+(defparameter *autoconf-win32* "@win32@")
 (defparameter *autoconf-ld-flags* "")
  
-(defparameter *maxima-source-root* "/home/robertdodier/tmp/maxima-git-build/maxima")
+(defparameter *maxima-source-root* "/home/robert/maxima/maxima-git/maxima")
 (defparameter *maxima-default-layout-autotools* "true")
