@@ -426,10 +426,7 @@
 (defvar *maxima-prolog* "")
 (defvar *maxima-epilog* "")
 
-;; These 2 are actually defined in init-cl.lisp.  This is to get rid
-;; of some compiler warnings (clisp).
-(defvar *maxima-initlisp*)
-(defvar *maxima-initmac*)
+(declare-top (special *maxima-initmac* *maxima-initlisp*))
 
 (defvar *maxima-quiet* nil)
 
