@@ -53,9 +53,6 @@
 
 (declare-top (special $file_search_lisp $file_search_maxima $file_search_demo $loadprint))
 
-(defun $load_search_dir ()
-  (pathname *default-pathname-defaults*))
-
 (defmfun load-and-tell (filename)
   (loadfile filename t ;; means this is a lisp-level call, not user-level.
 	    $loadprint))
@@ -572,50 +569,68 @@
 	  (test-count 0)
 	  (total-count 0)
 	  (error-count 0))
-      (time 
-       (loop with errs = '() for testentry in tests-to-run
-	     do
-	     (if (atom testentry)
-		 (progn
-		   (setf test-file testentry)
-		   (setf expected-failures nil))
-		 (progn
-		   (setf test-file (second testentry))
-		   (setf expected-failures (cddr testentry))))
-  
-	     (format t (intl:gettext "Running tests in ~a: ") (if (symbolp test-file)
-						   (subseq (print-invert-case test-file) 1)
-						   test-file))
-	     (or (errset
-		  (progn
-		    (multiple-value-setq (testresult test-count)
-		      (test-batch ($file_search test-file $file_search_tests)
-				  expected-failures
-				  :show-expected display_known_bugs
-				  :show-all display_all
-				  :showtime time))
-		    (setf testresult (rest testresult))
-		    (incf total-count test-count)
-		    (when testresult
-		      (incf error-count (length (cdr testresult)))
-		      (setq errs (append errs (list testresult))))))
-		 (progn
-		   (setq error-break-file (format nil "~a" test-file))
-		   (setq errs 
-			 (append errs 
-				 (list (list error-break-file "error break"))))
-		   (format t (intl:gettext "~%Caused an error break: ~a~%") test-file)))
-	     finally (cond ((null errs) 
-			    (format t (intl:gettext "~%~%No unexpected errors found out of ~:D tests.~%") total-count))
-			   (t (format t (intl:gettext "~%Error summary:~%"))
+      (flet
+	  ((testsuite ()
+	     (loop with errs = 'nil
+		   for testentry in tests-to-run
+		   do (if (atom testentry)
+			  (progn
+			    (setf test-file testentry)
+			    (setf expected-failures nil))
+			  (progn
+			    (setf test-file (second testentry))
+			    (setf expected-failures (cddr testentry))))
+		      (format t
+			      (intl:gettext "Running tests in ~a: ")
+			      (if (symbolp test-file)
+				  (subseq (print-invert-case test-file) 1)
+				  test-file))
+		      (or
+			(errset
+			  (progn
+			    (multiple-value-setq (testresult test-count)
+			      (test-batch ($file_search test-file $file_search_tests)
+					  expected-failures :show-expected display_known_bugs
+					  :show-all display_all :showtime time))
+			    (setf testresult (rest testresult))
+			    (incf total-count test-count)
+			    (when testresult
+			      (incf error-count (length (cdr testresult)))
+			      (setq errs (append errs (list testresult))))))
+			(progn
+			  (setq error-break-file (format nil "~a" test-file))
+			  (setq errs
+				(append errs
+					(list (list error-break-file "error break"))))
+			  (format t
+				  (intl:gettext "~%Caused an error break: ~a~%")
+				  test-file)))
+		   finally (cond
+			     ((null errs)
+			      (format t
+				      (intl:gettext
+				       "~%~%No unexpected errors found out of ~:d tests.~%")
+				      total-count))
+			     (t
+			      (format t (intl:gettext "~%Error summary:~%"))
 			      (mapcar
 			       #'(lambda (x)
 				   (let ((s (if (> (length (rest x)) 1) "s" "")))
-				     (format t (intl:gettext "Error~a found in ~a, problem~a:~%~a~%")
-					     s (first x) s (sort (rest x) #'<))))
+				     (format t
+					     (intl:gettext
+					      "Error~a found in ~a, problem~a:~%~a~%")
+					     s
+					     (first x)
+					     s
+					     (sort (rest x) #'<))))
 			       errs)
-			      (format t (intl:gettext "~&~:D test~P failed out of ~:D total tests.~%")
-				      error-count error-count total-count)))))))
+			      (format t
+				      (intl:gettext
+				       "~&~:d test~p failed out of ~:d total tests.~%")
+				      error-count
+				      error-count
+				      total-count))))))
+      (time (testsuite)))))
   '$done)
 
 ;; Convert a list of Maxima "keyword" arguments into the corresponding
